@@ -19,7 +19,7 @@ def deletetorrent(delpath=''):
             logger.info('正在删除文件:'+c_path+'...')
             os.remove(c_path)
 
-def changename(pah):
+def changename(path):
     if not 'win' in sys.platform:
         return path
     else:
